﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using AIOUSBNet;  // the namespace exposes the AIOUSB Class interface 

namespace Sample1
{
    
    public partial class Form1 : Form
    {
        public const int ERROR_SUCCESS = 0; // Win32 standard response code
        private const byte bmDifferential = 0x8; // const for Range Selection to indicate "Differential"
        private UInt32 ConfigBufSize = 20; // sizeof(Config);

        // One and only Device Index:
        public UInt32 DeviceIndex;
        private int NumberOfADChannelsToDisplay;

        public Form1()
        {
            InitializeComponent();
        }

        private UInt32 RedetectDevices()
        {
            AIOUSB.AIOUSB_ReloadDeviceLinks(); // redetects devices; generally just for convenience; do this first as DeviceIndices can change
            var di = AIOUSB.ResolveDeviceIndex(AIOUSB.diOnly);
            if (di == AIOUSB.diNone)
            {
                // handle more than one device detected, perhaps by allowing user to pick which deviceindex to use via a GetDevices() and QueryDeviceInfo() dialog
            }

            return di;
        }

        private void ExecuteButton_Click(object sender, EventArgs e)
        {
            ScanTimer.Stop();

            DeviceIndex = RedetectDevices();
            if (DeviceIndex == AIOUSB.diNone) // diNone also means "too many"
            {
                // handle "zero devices found" and/or "more than one device found" error
                return;
            }

            AIOUSB.ADC_SetCal(DeviceIndex, ":1TO1:");

            byte ADCRangeCode = 1; // ±10V input range: change here!
            byte[] ConfigBuf = new byte[21];

            for (int i = 0; i < 16; i++)
            {
                if (DifferentialCheckBox.Checked)
                    ConfigBuf[i] = (byte)(bmDifferential | ADCRangeCode); // can be different per channel pair; 
                else
                    ConfigBuf[i] = (byte)(ADCRangeCode) // can be different per channel
                ;
            }
            ConfigBuf[16] = 0; // not calibrate mode
            ConfigBuf[17] = 5; // timer scan start

            if (DifferentialCheckBox.Checked)
            {
                ConfigBuf[18] = 0x70; // channel 0 through 7
                NumberOfADChannelsToDisplay = 8;
            }
            else
            {
                ConfigBuf[18] = 0xF0; // channel 0 through F
                NumberOfADChannelsToDisplay = 16;
            }

            ConfigBuf[19] = 0; // no oversamples

            ConfigBuf[20] = 0x10; // set end-channel top-nybble

            var status = AIOUSB.ADC_SetConfig(DeviceIndex, ConfigBuf, ref ConfigBufSize);
            if (status != ERROR_SUCCESS)
            {
                // handle error
                return;
            }


            ExecuteButton.Enabled = false;
            StopButton.Enabled = true;

            ScanTimer.Start();
        }

        private void ScanTimer_Tick(object sender, EventArgs e)
        {
            double[] Volts = new double[128];

            var status = AIOUSB.ADC_GetScanV(DeviceIndex, Volts);  // acquire scan of ADC data
            if (status != ERROR_SUCCESS)
            {
                ScanTimer.Stop();
                MessageBox.Show("ADC_GetScanV Error!");
            }
            else
            {
                listBoxVoltage.Items.Clear(); 

                for (int I = 0; I < 32; ++I)  // change 32 for the number of channels your device has
                {
                    string strChVolt;
                    string formatString = "Ch {0,2:D2}: {1,8:F4}";
                    strChVolt = String.Format(formatString, I, Volts[I]);

                    listBoxVoltage.Items.Add(strChVolt); 
                }
            }
        }

        private void StopButton_Click(object sender, EventArgs e)
        {
            ScanTimer.Stop();
            ExecuteButton.Enabled = true;
            StopButton.Enabled = false;
        }
    }
}
